@@ -6,9 +6,16 @@ module PuppetMetadata
   #
   # @see https://endoflife.software/operating-systems
   class OperatingSystem
+    # please add new OSes sorted alphabetically
+
     # The EOL dates for the various operating systems
     # @see .eol_date
     EOL_DATES = {
+      # https://almalinux.org/ FAQ at the bottom
+      'AlmaLinux' => {
+        '9' => nil,
+        '8' => '2029-05-31',
+      },
       # https://endoflife.software/operating-systems/linux/centos
       'CentOS' => {
         '9' => nil, # EOL Date is not yet announced.
@@ -71,6 +78,19 @@ module PuppetMetadata
         '2' => '2005-04-11',
         '1' => '2004-09-20',
       },
+      # https://endoflife.software/operating-systems/unix-like-bsd/freebsd
+      'FreeBSD' => {
+        '13' => '2026-01-31',
+        '12' => '2024-06-30',
+        '11' => '2021-09-30',
+        '10' => '2018-10-31',
+        '9' => '2016-12-31',
+        '8' => '2015-08-01',
+        '7' => '2013-02-28',
+        '6' => '2010-11-30',
+        '5' => '2008-05-31',
+        '4' => '2007-01-31',
+      },
       # https://endoflife.software/operating-systems/linux/red-hat-enterprise-linux-rhel
       'RedHat' => {
         # TODO: EOL is standard support, not the extended life cycle
@@ -81,8 +101,16 @@ module PuppetMetadata
         '4' => '2012-02-29',
         '3' => '2010-10-31',
       },
+      # https://endoflife.date/rocky-linux
+      'Rocky' => {
+        '9' => nil,
+        '8' => '2029-05-31',
+      },
       # https://endoflife.software/operating-systems/linux/ubuntu
       'Ubuntu' => {
+        '22.04' => '2027-04-15',
+        '21.10' => '2022-07-15',
+        '20.10' => '2021-07-15',
         '20.04' => '2025-04-15',
         '19.10' => '2020-07-15',
         '19.04' => '2020-01-15',
@@ -158,6 +186,16 @@ module PuppetMetadata
         releases = EOL_DATES[operatingsystem]
         releases&.keys&.max_by { |release| Gem::Version.new(release) }
       end
+
+      # Return an array of all Operating System versions that aren't EoL
+      # @param [String] operatingsystem The operating system
+      # @return [Array] All Operating System versions that aren't EoL today
+      def supported_releases(operatingsystem)
+        releases = EOL_DATES[operatingsystem]
+        today = Date.today
+        releases.select { |release, eol_date| !eol_date || Date.parse(eol_date) > today }.keys.
+          sort_by { |release| Gem::Version.new(release) }
+      end
     end
   end
 end
